@@ -1,7 +1,7 @@
 package AnySan::Provider::Slack;
 use strict;
 use warnings;
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 use base 'AnySan::Provider';
 our @EXPORT = qw(slack);
@@ -49,7 +49,8 @@ sub bot {
 sub start {
     my $self = shift;
 
-    my $rtm = AnyEvent::SlackRTM->new($self->{config}{token});
+    my $client_opt = $self->{config}{timeout} ? { timeout => $self->{config}{timeout} } : undef;
+    my $rtm = AnyEvent::SlackRTM->new($self->{config}{token}, $client_opt);
     $rtm->on('hello' => sub {
         # create hash table of users
         my $users = {};
